
# Version 1.0.0

The first official release of X-ANFIS includes:

+ Add infors (CODE_OF_CONDUCT.md, MANIFEST.in, LICENSE, requirements.txt)
+ Add helpers modules (membership_family, metric_util, scaler_util, validator, preprocessor)
+ Add wrapper for different ANFIS models (BaseAnfis, BaseClassicAnfis, BaseGdAnfis, BaseBioAnfis)
+ Add wrapper for different ANFIS models (AnfisRegressor, AnfisClassifier, GdAnfisRegressor, GdAnfisClassifier, BioAnfisRegressor, BioAnfisClassifier)
+ Add publish workflow
+ Add examples and tests folders
